@@ -16,7 +16,10 @@
  */
 package org.apache.commons.io;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.File;
 import java.io.FileFilter;
@@ -35,7 +38,6 @@ import org.junit.Test;
 /**
  * This is used to test DirectoryWalker for correctness.
  *
- * @version $Id: DirectoryWalkerTestCase.java 1686260 2015-06-18 15:57:56Z krosenvold $
  * @see DirectoryWalker
  *
  */
@@ -240,7 +242,7 @@ public class DirectoryWalkerTestCase {
      * Extract the directories.
      */
     private List<File> directoriesOnly(final Collection<File> results) {
-        final List<File> list = new ArrayList<File>(results.size());
+        final List<File> list = new ArrayList<>(results.size());
         for (final File file : results) {
             if (file.isDirectory()) {
                 list.add(file);
@@ -253,7 +255,7 @@ public class DirectoryWalkerTestCase {
      * Extract the files.
      */
     private List<File> filesOnly(final Collection<File> results) {
-        final List<File> list = new ArrayList<File>(results.size());
+        final List<File> list = new ArrayList<>(results.size());
         for (final File file : results) {
             if (file.isFile()) {
                 list.add(file);
@@ -263,7 +265,7 @@ public class DirectoryWalkerTestCase {
     }
 
     /**
-     * Create an name filter containg the names of the files
+     * Create a name filter containing the names of the files
      * in the array.
      */
     private static IOFileFilter createNameFilter(final File[] files) {
@@ -389,7 +391,7 @@ public class DirectoryWalkerTestCase {
 
         /** find files. */
         protected List<File> find(final File startDirectory) {
-           final List<File> results = new ArrayList<File>();
+           final List<File> results = new ArrayList<>();
            try {
                walk(startDirectory, results);
            } catch(final IOException ex) {
@@ -448,7 +450,7 @@ public class DirectoryWalkerTestCase {
 
         /** find files. */
         protected List<File> find(final File startDirectory) throws IOException {
-           final List<File> results = new ArrayList<File>();
+           final List<File> results = new ArrayList<>();
            walk(startDirectory, results);
            return results;
         }
@@ -499,7 +501,7 @@ public class DirectoryWalkerTestCase {
 
         /** find files. */
         protected List<File> find(final File startDirectory) throws IOException {
-           results = new ArrayList<File>();
+           results = new ArrayList<>();
            walk(startDirectory, results);
            return results;
         }
@@ -552,7 +554,7 @@ public class DirectoryWalkerTestCase {
 
         /** find files. */
         protected List<String> find(final File startDirectory) {
-           final List<String> results = new ArrayList<String>();
+           final List<String> results = new ArrayList<>();
            try {
                walk(startDirectory, results);
            } catch(final IOException ex) {
