@@ -16,25 +16,30 @@
  */
 package org.apache.commons.io;
 
-import org.apache.commons.io.testtools.FileBasedTestCase;
-import org.junit.Assert;
-import org.junit.Test;
-
-import java.io.*;
-import java.util.Locale;
-
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.fail;
 
+import java.io.BufferedReader;
+import java.io.ByteArrayInputStream;
+import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.io.OutputStream;
+import java.util.Locale;
+
+import org.junit.Assert;
+import org.junit.Test;
+
 /**
  * This is used to test FileSystemUtils.
  *
- * @version $Id: FileSystemUtilsTestCase.java 1718944 2015-12-09 19:50:30Z krosenvold $
  */
-public class FileSystemUtilsTestCase extends FileBasedTestCase {
+public class FileSystemUtilsTestCase {
 
     //-----------------------------------------------------------------------
     @Test
+    @SuppressWarnings("deprecation") // testing decrecated code
     public void testGetFreeSpace_String() throws Exception {
         // test coverage, as we can't check value
         if (File.separatorChar == '/') {
@@ -53,34 +58,33 @@ public class FileSystemUtilsTestCase extends FileBasedTestCase {
             }
             final Process proc = Runtime.getRuntime().exec(cmd);
             boolean kilobyteBlock = true;
-            BufferedReader r = null;
-            try {
-                r = new BufferedReader(new InputStreamReader(proc.getInputStream()));
+            try (BufferedReader r = new BufferedReader(new InputStreamReader(proc.getInputStream()))){
                 final String line = r.readLine();
                 Assert.assertNotNull("Unexpected null line", line);
                 if (line.contains("512")) {
                     kilobyteBlock = false;
                 }
-            } finally {
-                IOUtils.closeQuietly(r);
             }
 
             // now perform the test
-            @SuppressWarnings("deprecation")
-            final
-            long free = FileSystemUtils.freeSpace("/");
+            final long free = FileSystemUtils.freeSpace("/");
             final long kb = FileSystemUtils.freeSpaceKb("/");
+            // Assume disk space does not fluctuate
+            // more than 1% between the above two calls;
+            // this also also small enough to verifiy freeSpaceKb uses
+            // kibibytes (1024) instead of SI kilobytes (1000)
+            final double acceptableDelta = kb * 0.01d;
             if (kilobyteBlock) {
-                assertEquals(free, kb, 256d);
+                assertEquals(free, kb, acceptableDelta);
             } else {
-                assertEquals(free / 2d, kb, 256d);
+                assertEquals(free / 2d, kb, acceptableDelta);
             }
         } else {
-            @SuppressWarnings("deprecation")
-            final
-            long bytes = FileSystemUtils.freeSpace("");
+            final long bytes = FileSystemUtils.freeSpace("");
             final long kb = FileSystemUtils.freeSpaceKb("");
-            assertEquals((double) bytes / 1024, kb, 256d);
+            // Assume disk space does not fluctuate more than 1%
+            final double acceptableDelta = kb * 0.01d;
+            assertEquals((double) bytes / 1024, kb, acceptableDelta);
         }
     }
 
