@@ -16,11 +16,9 @@
  */
 package org.apache.commons.io;
 
-import org.apache.commons.io.output.ByteArrayOutputStream;
-import org.apache.commons.io.testtools.FileBasedTestCase;
-import org.apache.commons.io.testtools.TestUtils;
-import org.apache.commons.io.testtools.YellOnFlushAndCloseOutputStream;
-import org.junit.Test;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
@@ -28,23 +26,22 @@ import java.io.Writer;
 import java.util.Arrays;
 import java.util.List;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.apache.commons.io.output.ByteArrayOutputStream;
+import org.apache.commons.io.testtools.TestUtils;
+import org.apache.commons.io.testtools.YellOnFlushAndCloseOutputStream;
+import org.junit.Test;
 
 /**
  * JUnit tests for IOUtils write methods.
  *
- * @version $Id: IOUtilsWriteTestCase.java 1718944 2015-12-09 19:50:30Z krosenvold $
  * @see IOUtils
  */
 @SuppressWarnings("deprecation") // includes tests for deprecated methods
-public class IOUtilsWriteTestCase extends FileBasedTestCase {
+public class IOUtilsWriteTestCase {
 
     private static final int FILE_SIZE = 1024 * 4 + 1;
 
-
-    private final byte[] inData = TestUtils.generateTestData((long) FILE_SIZE);
+    private final byte[] inData = TestUtils.generateTestData(FILE_SIZE);
 
     // ----------------------------------------------------------------
     // Tests
