@@ -16,22 +16,6 @@
  */
 package org.apache.commons.io.input;
 
-import java.io.*;
-import java.nio.charset.Charset;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
-import java.util.concurrent.Executor;
-import java.util.concurrent.ScheduledThreadPoolExecutor;
-
-import org.apache.commons.io.Charsets;
-import org.apache.commons.io.FileUtils;
-import org.apache.commons.io.IOUtils;
-import org.apache.commons.io.testtools.FileBasedTestCase;
-import org.apache.commons.io.testtools.TestUtils;
-import org.junit.After;
-import org.junit.Test;
-
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -39,12 +23,46 @@ import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+import java.io.BufferedOutputStream;
+import java.io.BufferedReader;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.FileOutputStream;
+import java.io.FileWriter;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.io.OutputStreamWriter;
+import java.io.RandomAccessFile;
+import java.io.Writer;
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
+import java.util.concurrent.Executor;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
+
+import org.apache.commons.io.FileUtils;
+import org.apache.commons.io.IOUtils;
+import org.apache.commons.io.testtools.TestUtils;
+import org.junit.After;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
+
 /**
  * Tests for {@link Tailer}.
  *
- * @version $Id: TailerTest.java 1721380 2015-12-22 12:13:05Z krosenvold $
  */
-public class TailerTest extends FileBasedTestCase {
+public class TailerTest {
+
+    @Rule
+    public TemporaryFolder temporaryFolder = new TemporaryFolder();
+
+    private File getTestDirectory() {
+        return temporaryFolder.getRoot();
+    }
 
     private Tailer tailer;
 
@@ -52,10 +70,7 @@ public class TailerTest extends FileBasedTestCase {
     public void tearDown() throws Exception {
         if (tailer != null) {
             tailer.stop();
-            TestUtils.sleep(1000);
         }
-        FileUtils.deleteDirectory(getTestDirectory());
-        TestUtils.sleep(1000);
     }
 
     @Test
@@ -64,12 +79,12 @@ public class TailerTest extends FileBasedTestCase {
 
         final File file = new File(getTestDirectory(), "testLongFile.txt");
         createFile(file, 0);
-        final Writer writer = new FileWriter(file, true);
-        for (int i = 0; i < 100000; i++) {
-            writer.write("LineLineLineLineLineLineLineLineLineLine\n");
+        try (final Writer writer = new FileWriter(file, true)) {
+            for (int i = 0; i < 100000; i++) {
+                writer.write("LineLineLineLineLineLineLineLineLineLine\n");
+            }
+            writer.write("SBTOURIST\n");
         }
-        writer.write("SBTOURIST\n");
-        IOUtils.closeQuietly(writer);
 
         final TestTailerListener listener = new TestTailerListener();
         tailer = new Tailer(file, listener, delay, false);
@@ -110,7 +125,6 @@ public class TailerTest extends FileBasedTestCase {
         listener.clear();
     }
 
-    @SuppressWarnings("deprecation") // unavoidable until Java 7
     @Test
     public void testMultiByteBreak() throws Exception {
         System.out.println("testMultiByteBreak() Default charset: "+Charset.defaultCharset().displayName());
@@ -122,16 +136,14 @@ public class TailerTest extends FileBasedTestCase {
         final String osname = System.getProperty("os.name");
         final boolean isWindows = osname.startsWith("Windows");
         // Need to use UTF-8 to read & write the file otherwise it can be corrupted (depending on the default charset)
-        final Charset charsetUTF8 = Charsets.UTF_8;
+        final Charset charsetUTF8 = StandardCharsets.UTF_8;
         tailer = new Tailer(file, charsetUTF8, listener, delay, false, isWindows, 4096);
         final Thread thread = new Thread(tailer);
         thread.start();
 
-        Writer out = new OutputStreamWriter(new FileOutputStream(file), charsetUTF8);
-        BufferedReader reader = null;
-        try{
-            List<String> lines = new ArrayList<String>();
-            reader = new BufferedReader(new InputStreamReader(new FileInputStream(origin), charsetUTF8));
+        try (Writer out = new OutputStreamWriter(new FileOutputStream(file), charsetUTF8);
+             BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(origin), charsetUTF8))) {
+            final List<String> lines = new ArrayList<>();
             String line;
             while((line = reader.readLine()) != null){
                 out.write(line);
@@ -141,22 +153,18 @@ public class TailerTest extends FileBasedTestCase {
             out.close(); // ensure data is written
 
            final long testDelayMillis = delay * 10;
-            TestUtils.sleep(testDelayMillis);
-           List<String> tailerlines = listener.getLines();
+           TestUtils.sleep(testDelayMillis);
+           final List<String> tailerlines = listener.getLines();
            assertEquals("line count",lines.size(),tailerlines.size());
            for(int i = 0,len = lines.size();i<len;i++){
                final String expected = lines.get(i);
                final String actual = tailerlines.get(i);
                if (!expected.equals(actual)) {
-                   fail("Line: " + i 
-                           + "\nExp: (" + expected.length() + ") " + expected 
+                   fail("Line: " + i
+                           + "\nExp: (" + expected.length() + ") " + expected
                            + "\nAct: (" + actual.length() + ") "+ actual);
                }
            }
-        }finally{
-            tailer.stop();
-            IOUtils.closeQuietly(reader);
-            IOUtils.closeQuietly(out);
         }
     }
 
@@ -167,32 +175,25 @@ public class TailerTest extends FileBasedTestCase {
         final File file = new File(getTestDirectory(), "tailer2-test.txt");
         createFile(file, 0);
         final TestTailerListener listener = new TestTailerListener();
-        final Tailer tailer = new Tailer(file, listener, delay, false);
+        tailer = new Tailer(file, listener, delay, false);
         final Thread thread = new Thread(tailer);
         thread.start();
 
         // Write some lines to the file
-        final FileWriter writer = null;
-        try {
-            writeString(file, "Line");
+        writeString(file, "Line");
 
-            TestUtils.sleep(delay * 2);
-            List<String> lines = listener.getLines();
-            assertEquals("1 line count", 0, lines.size());
+        TestUtils.sleep(delay * 2);
+        List<String> lines = listener.getLines();
+        assertEquals("1 line count", 0, lines.size());
 
-            writeString(file, " one\n");
-            TestUtils.sleep(delay * 2);
-            lines = listener.getLines();
+        writeString(file, " one\n");
+        TestUtils.sleep(delay * 2);
+        lines = listener.getLines();
 
-            assertEquals("1 line count", 1, lines.size());
-            assertEquals("1 line 1", "Line one", lines.get(0));
+        assertEquals("1 line count", 1, lines.size());
+        assertEquals("1 line 1", "Line one", lines.get(0));
 
-            listener.clear();
-        } finally {
-            tailer.stop();
-            TestUtils.sleep(delay * 2);
-            IOUtils.closeQuietly(writer);
-        }
+        listener.clear();
     }
 
     @Test
@@ -259,9 +260,6 @@ public class TailerTest extends FileBasedTestCase {
         assertEquals("Expected init to be called", 1 , listener.initialised);
         assertEquals("fileNotFound should not be called", 0 , listener.notFound);
         assertEquals("fileRotated should be be called", 1 , listener.rotated);
-        tailer.stop();
-        tailer=null;
-
     }
 
     @Test
@@ -300,12 +298,9 @@ public class TailerTest extends FileBasedTestCase {
             throw new IOException("Cannot create file " + file
                     + " as the parent directory does not exist");
         }
-        final BufferedOutputStream output =
-                new BufferedOutputStream(new FileOutputStream(file));
-        try {
+        try (final BufferedOutputStream output =
+                new BufferedOutputStream(new FileOutputStream(file))) {
             TestUtils.generateTestData(output, size);
-        } finally {
-            IOUtils.closeQuietly(output);
         }
 
         // try to make sure file is found
@@ -330,31 +325,22 @@ public class TailerTest extends FileBasedTestCase {
 
     /** Append some lines to a file */
     private void write(final File file, final String... lines) throws Exception {
-        FileWriter writer = null;
-        try {
-            writer = new FileWriter(file, true);
+        try (FileWriter writer = new FileWriter(file, true)) {
             for (final String line : lines) {
                 writer.write(line + "\n");
             }
-        } finally {
-            IOUtils.closeQuietly(writer);
         }
     }
 
     /** Append a string to a file */
     private void writeString(final File file, final String ... strings) throws Exception {
-        FileWriter writer = null;
-        try {
-            writer = new FileWriter(file, true);
+        try (FileWriter writer = new FileWriter(file, true)) {
             for (final String string : strings) {
                 writer.write(string);
             }
-        } finally {
-            IOUtils.closeQuietly(writer);
         }
     }
 
-
     @Test
     public void testStopWithNoFile() throws Exception {
         final File file = new File(getTestDirectory(),"nosuchfile");
@@ -365,7 +351,6 @@ public class TailerTest extends FileBasedTestCase {
         tailer = Tailer.create(file, listener, delay, false);
         TestUtils.sleep(idle);
         tailer.stop();
-        tailer=null;
         TestUtils.sleep(delay+idle);
         assertNull("Should not generate Exception", listener.exception);
         assertEquals("Expected init to be called", 1 , listener.initialised);
@@ -385,13 +370,12 @@ public class TailerTest extends FileBasedTestCase {
         // Use a long delay to try to make sure the test thread calls interrupt() while the tailer thread is sleeping.
         final int delay = 1000;
         final int idle = 50; // allow time for thread to work
-        Tailer tailer = new Tailer(file, listener, delay, false, 4096);
+        tailer = new Tailer(file, listener, delay, false, 4096);
         final Thread thread = new Thread(tailer);
         thread.setDaemon(true);
         thread.start();
         TestUtils.sleep(idle);
         thread.interrupt();
-        tailer = null;
         TestUtils.sleep(delay + idle);
         assertNotNull("Missing InterruptedException", listener.exception);
         assertTrue("Unexpected Exception: " + listener.exception, listener.exception instanceof InterruptedException);
@@ -413,7 +397,6 @@ public class TailerTest extends FileBasedTestCase {
         exec.execute(tailer);
         TestUtils.sleep(idle);
         tailer.stop();
-        tailer=null;
         TestUtils.sleep(delay+idle);
         assertNull("Should not generate Exception", listener.exception);
         assertEquals("Expected init to be called", 1 , listener.initialised);
@@ -443,12 +426,6 @@ public class TailerTest extends FileBasedTestCase {
         assertEquals("line 2", "LF", lines.get(1));
         assertEquals("line 3", "CR", lines.get(2));
         assertEquals("line 4", "CRCR\r", lines.get(3));
-
-        // Stop
-        tailer.stop();
-        tailer=null;
-        thread.interrupt();
-        TestUtils.sleep(testDelayMillis);
     }
 
     /**
@@ -469,6 +446,7 @@ public class TailerTest extends FileBasedTestCase {
 
         volatile int reachedEndOfFile = 0;
 
+        @Override
         public void handle(final String line) {
             lines.add(line);
         }
@@ -481,22 +459,27 @@ public class TailerTest extends FileBasedTestCase {
             lines.clear();
         }
 
+        @Override
         public void handle(final Exception e) {
             exception = e;
         }
 
+        @Override
         public void init(final Tailer tailer) {
             initialised++; // not atomic, but OK because only updated here.
         }
 
+        @Override
         public void fileNotFound() {
             notFound++; // not atomic, but OK because only updated here.
         }
 
+        @Override
         public void fileRotated() {
             rotated++; // not atomic, but OK because only updated here.
         }
 
+        @Override
         public void endOfFileReached() {
             reachedEndOfFile++; // not atomic, but OK because only updated here.
         }
