@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,13 +16,12 @@
  */
 package org.apache.commons.io.output;
 
+import static org.junit.Assert.fail;
+
 import java.io.IOException;
 
-import junit.framework.TestCase;
 import org.junit.Test;
 
-import static org.junit.Assert.fail;
-
 /**
  * JUnit Test Case for {@link ClosedOutputStream}.
  */
@@ -30,19 +29,29 @@ public class ClosedOutputStreamTest {
 
     /**
      * Test the <code>write(b)</code> method.
-     * @throws Exception 
+     * @throws Exception
      */
     @Test
     public void testRead() throws Exception {
-        ClosedOutputStream cos = null;
-        try {
-            cos = new ClosedOutputStream();
+        try (ClosedOutputStream cos = new ClosedOutputStream()) {
             cos.write('x');
             fail("write(b)");
         } catch (final IOException e) {
             // expected
-        } finally {
-            cos.close();
+        }
+    }
+
+    /**
+     * Test the <code>flush()</code> method.
+     * @throws Exception
+     */
+    @Test
+    public void testFlush() throws Exception {
+        try (ClosedOutputStream cos = new ClosedOutputStream()) {
+            cos.flush();
+            fail("flush()");
+        } catch (final IOException e) {
+            // expected
         }
     }
 
